==> haskell-cpphs-1.20.4-1-i686.pkg.tar.xz: usr/share/haskell/register/haskell-cpphs.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cpphs
version: 1.20.4
id: cpphs-1.20.4-LO4krdoPFZv9dMR7FlkcwT
key: cpphs-1.20.4-LO4krdoPFZv9dMR7FlkcwT
license: LGPL
copyright: 2004-2017, Malcolm Wallace
maintainer: Malcolm Wallace <Malcolm.Wallace@me.com>
homepage: http://projects.haskell.org/cpphs/
synopsis: A liberalised re-implementation of cpp, the C pre-processor.
description:
    Cpphs is a re-implementation of the C pre-processor that is both
    more compatible with Haskell, and itself written in Haskell so
    that it can be distributed with compilers.
    .
    This version of the C pre-processor is pretty-much
    feature-complete and compatible with traditional (K&R)
    pre-processors.  Additional features include: a plain-text mode;
    an option to unlit literate code files; and an option to turn
    off macro-expansion.
category: Development
author: Malcolm Wallace <Malcolm.Wallace@me.com>
exposed: True
exposed-modules:
    Language.Preprocessor.Cpphs Language.Preprocessor.Unlit
hidden-modules: Language.Preprocessor.Cpphs.CppIfdef
                Language.Preprocessor.Cpphs.HashDefine
                Language.Preprocessor.Cpphs.MacroPass
                Language.Preprocessor.Cpphs.Options
                Language.Preprocessor.Cpphs.Position
                Language.Preprocessor.Cpphs.ReadFirst
                Language.Preprocessor.Cpphs.RunCpphs
                Language.Preprocessor.Cpphs.SymTab
                Language.Preprocessor.Cpphs.Tokenise
abi: a497724d5f47e315214a5bb73bbaeb52
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/cpphs-1.20.4
library-dirs: /usr/lib/ghc-8.0.1/site-local/cpphs-1.20.4
data-dir: /usr/share/i386-linux-ghc-8.0.1/cpphs-1.20.4
hs-libraries: HScpphs-1.20.4-LO4krdoPFZv9dMR7FlkcwT
depends:
    base-4.9.0.0 directory-1.2.6.2 filepath-1.4.1.0
    old-locale-1.0.0.7-6glXNhHF891B41ZfuI8hU8
    old-time-1.1.0.3-IcvdkJUsE9M8t3io8peAEp
    polyparse-1.12-9D0YnY3UMon43vdSjbfwCd
haddock-interfaces: /usr/share/doc/haskell-cpphs/html/cpphs.haddock
haddock-html: /usr/share/doc/haskell-cpphs/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cpphs-1.20.5-2-i686.pkg.tar.xz: usr/share/haskell/register/haskell-cpphs.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cpphs
version: 1.20.5
id: cpphs-1.20.5-9Lrl39xU7l95nscj9g2g6B
key: cpphs-1.20.5-9Lrl39xU7l95nscj9g2g6B
license: LGPL
copyright: 2004-2017, Malcolm Wallace
maintainer: Malcolm Wallace <Malcolm.Wallace@me.com>
homepage: http://projects.haskell.org/cpphs/
synopsis: A liberalised re-implementation of cpp, the C pre-processor.
description:
    Cpphs is a re-implementation of the C pre-processor that is both
    more compatible with Haskell, and itself written in Haskell so
    that it can be distributed with compilers.
    .
    This version of the C pre-processor is pretty-much
    feature-complete and compatible with traditional (K&R)
    pre-processors.  Additional features include: a plain-text mode;
    an option to unlit literate code files; and an option to turn
    off macro-expansion.
category: Development
author: Malcolm Wallace <Malcolm.Wallace@me.com>
exposed: True
exposed-modules:
    Language.Preprocessor.Cpphs Language.Preprocessor.Unlit
hidden-modules: Language.Preprocessor.Cpphs.CppIfdef
                Language.Preprocessor.Cpphs.HashDefine
                Language.Preprocessor.Cpphs.MacroPass
                Language.Preprocessor.Cpphs.Options
                Language.Preprocessor.Cpphs.Position
                Language.Preprocessor.Cpphs.ReadFirst
                Language.Preprocessor.Cpphs.RunCpphs
                Language.Preprocessor.Cpphs.SymTab
                Language.Preprocessor.Cpphs.Tokenise
abi: 456002050e9ff22df33513c46c6dff19
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/cpphs-1.20.5
library-dirs: /usr/lib/ghc-8.0.1/site-local/cpphs-1.20.5
data-dir: /usr/share/i386-linux-ghc-8.0.1/cpphs-1.20.5
hs-libraries: HScpphs-1.20.5-9Lrl39xU7l95nscj9g2g6B
depends:
    base-4.9.0.0 directory-1.2.6.2
    old-locale-1.0.0.7-6glXNhHF891B41ZfuI8hU8
    old-time-1.1.0.3-IcvdkJUsE9M8t3io8peAEp
    polyparse-1.12-xXhcRyjLZ1DCtbZ1LsaMo
haddock-interfaces: /usr/share/doc/haskell-cpphs/html/cpphs.haddock
haddock-html: /usr/share/doc/haskell-cpphs/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
